/**
 * Copyright (C) 2009 Jasig, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jasig.cas3.extensions.clearpass.integration.uportal;

import org.jasig.portal.security.ISecurityContextFactory;
import org.jasig.portal.security.ISecurityContext;
import org.jasig.portal.security.provider.cas.CasAssertionSecurityContext;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.Properties;
import java.io.InputStream;
import java.io.IOException;

/**
 * 
 *
 * @author Scott Battaglia
 * @version $Revision$ $Date$
 * @since 1.0.0.GA
 */
public final class PasswordCachingCasAssertionSecurityContextFactory implements ISecurityContextFactory {

    private final static String CLEARPASS_CAS_URL_PROPERTY = PasswordCachingCasAssertionSecurityContextFactory.class.getName()+".clearPassCasUrl";

    private final Log log = LogFactory.getLog(getClass());

    private final String clearPassUrl;

    public PasswordCachingCasAssertionSecurityContextFactory() {
        final Resource resource = new ClassPathResource("properties/security.properties", getClass().getClassLoader());
        final Properties securityProperties = new Properties();
        InputStream inputStream = null;

        try {
            inputStream = resource.getInputStream();
            securityProperties.load(inputStream);
            this.clearPassUrl = securityProperties.getProperty(CLEARPASS_CAS_URL_PROPERTY);          
        } catch (final Exception e) {
            log.warn("ClearPass URL Not found in security.properties.  Falling back to CasAssertionSecurityContext. ClearPass DISABLED.");
            throw new RuntimeException(e);
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (final IOException e) {
                    //nothing to do
                }
            }
        }
    }

    public ISecurityContext getSecurityContext() {
        if (this.clearPassUrl != null) {
            return new PasswordCachingCasAssertionSecurityContext(this.clearPassUrl);
        }

        return new CasAssertionSecurityContext();
    }
}
